@@ -1,16 +1,6 @@
 # -*- coding: utf-8 -*-
-#
-#  Copyright (c) 2007-2012 Guilherme Gondim and contributors
-#
-#  This file is part of Django Diário.
-#
-#  Django Diário is free software under terms of the GNU Lesser
-#  General Public License version 3 (LGPLv3) as published by the Free
-#  Software Foundation. See the file README for copying conditions.
-#
 
-"""
-Default Diário application settings.
+"""Default Diário application settings.
 
 If you do not configure the settings below in your own project settings.py,
 they will assume default values::
@@ -27,6 +17,7 @@ they will assume default values::
 
     DIARIO_NUM_LATEST
         Number of latest itens on object_list view. Default: 10.
+
 """
 
 from django.conf import settings
