@@ -1,17 +1,6 @@
 # -*- coding: utf-8 -*-
-#
-#  Copyright (c) 2009-2012 Guilherme Gondim and contributors
-#
-#  This file is part of Django Diário.
-#
-#  Django Diário is free software under terms of the GNU Lesser
-#  General Public License version 3 (LGPLv3) as published by the Free
-#  Software Foundation. See the file README for copying conditions.
-#
 
-"""
-URL definitions for weblog entries divided by author.
-"""
+"""URL definitions for weblog entries divided by author"""
 
 from django.conf.urls.defaults import *
 
